==> teide-0.0.9.tgz: package/teide.js <==
#!/usr/bin/env node

var fs = require('fs');
var path = require('path');
var glob = require('glob');
var open = require('open');
var express = require('express');
var portfinder = require('portfinder');
var bodyParser = require('body-parser');

var app = express();
app.use(bodyParser.json());
app.use(express.static(__dirname));

var spaces = new RegExp(/\s/g);
for (var x in fs) {
    if (typeof fs[x] === 'function' && x.substring(x.length - 4) !== 'Sync') {
        var str = fs[x].toString();
        var plain = str.replace(spaces, '');
        var args = plain.substring(plain.indexOf('(') + 1, plain.indexOf(')')).split(',');
        (function(x) {
            app.post('/fs/' + x, function(req, res) {
                if (req.body) {
                    var args = req.body.args;
                    args.push(function callback(err, result) {
                        var out = {'err': err, 'res': result};
                        res.send(out);
                    });
                    fs[x].apply(this, args);
                }
            });
        })(x);
    }
}

// Read files with normalized line endings
var carriages = new RegExp(/\r/g);
app.post('/fs/cat', function(req, resp) {
    var out = {'res': []};
    var args = req.body.args;
	
	args.push(function callback(err, filedata) {
		if (err) {
			console.log(err);
			out.err = err;
		} else {
			out.res = filedata.replace(carriages, '');
		}
		resp.send(out);
	});
	
	fs.readFile.apply(this, args);
});

// List files and folders in a directory
app.post('/fs/listdir', function(req, resp) {
    var out = {'res': []};
    var args = req.body.args;
    
    function onfinish() {
        var files = out.res.filter(function(item) { return item.type === 'file'; });
        var folders = out.res.filter(function(item) { return item.type === 'folder'; });
        function sortFunction(item1, item2) {
            return item1.name.localeCompare(item2.name);
        }
        files.sort(sortFunction);
        folders.sort(sortFunction);
        out.res = [{'name': '..', 'path': path.resolve(args[0], '..'), type: 'folder'}].concat(folders).concat(files);
        return resp.send(out);
    }
    
    args.push(function callback(err, filelist) {
        if (err) {
            out['err'] = err;
			//console.log(err);
            return resp.send(out);
        
        } else if (filelist.length == 0) {
            onfinish();

        } else {
            filelist.forEach(function(filename) {
                fs.stat(path.join(args[0], filename), function(err, fileobj) {
                    if (err) {
                        out['err'] += err + '\n';
                        //console.log(err);
                    } else {
                        out.res.push({
                            'name': filename,
                            'path': path.normalize(path.join(args[0], filename)).split(path.sep).join('/'),
                            'type': fileobj.isFile() ? 'file' : 'folder'
                        });
                    }

                    if (out.res.length === filelist.length) {
                        onfinish();
                    }
                });
            })
        }
    });

    fs.readdir.apply(this, args);
});

// Perform a glob search for a pattern
app.post('/fs/glob', function(req, resp) {
    var out = {'res': []};
    var args = req.body.args;
    glob(args[0], function (err, files) {
        if (err) {
            console.log(err);
            out.err = err;
        } else {
            out.res = files;
        }
        resp.send(out);
    });
});

// Create a file if it does not exist, otherwise update timestamp
app.post('/fs/touch', function(req, resp) {
    var out = {'res': []};
    var args = req.body.args;

    // First check if it's a file or a folder
    fs.stat(args[0], function(err, fileobj) {
        if (err) {
            out['err'] += err + '\n';
            console.log(err);
            resp.send(out);

        // If it's a folder, just return info
        } else if (!fileobj.isFile()) {
            out.res = {'isFile': false};
            resp.send(out);

        // Otherwise, open and close the file
        } else {
          fs.open(args[0], 'a', function (err, fd) {
              if (err) {
                  console.log(err);
                  out.err = err;
                  resp.send(out);
              } else {
                  fs.close(fd, function(err) {
                      if (err) {
                          console.log(err);
                          out.err = err;
                      } else {
                          out.res = {'isFile': true};
                      }
                      resp.send(out);
                  });
              }
          });
        }
    });
});

// Workaround for https://github.com/PolymerElements/neon-animation/issues/184
app.get('/node_modules/@polymer/web-animations-js/web-animations-next-lite.min.js', function(req, resp) {
    resp.redirect('/node_modules/web-animations-js/web-animations-next-lite.min.js');
});

portfinder.getPort(function (err, port) {
    if (err) {
        console.log(err);
    } else {
        var url = 'http://localhost:' + port;
        setTimeout(function() {
            open(url);
        }, 1000);
        console.log('Listening on ' + url);
        app.listen(port);
    }
});

==> teide-0.0.15.tgz: package/teide.js <==
#!/usr/bin/env node

var fs = require('fs');
var path = require('path');
var glob = require('glob');
var open = require('open');
var express = require('express');
var portfinder = require('portfinder');
var bodyParser = require('body-parser');

var app = express();
app.use(bodyParser.json({limit: '128mb'}));
app.use(express.static(__dirname));

var spaces = new RegExp(/\s/g);
for (var x in fs) {
    if (typeof fs[x] === 'function' && x.substring(x.length - 4) !== 'Sync') {
        var str = fs[x].toString();
        var plain = str.replace(spaces, '');
        var args = plain.substring(plain.indexOf('(') + 1, plain.indexOf(')')).split(',');
        (function(x) {
            app.post('/fs/' + x, function(req, res) {
                if (req.body) {
                    var args = req.body.args;
                    args.push(function callback(err, result) {
                        var out = {'err': err, 'res': result};
                        res.send(out);
                    });
                    fs[x].apply(this, args);
                }
            });
        })(x);
    }
}

// Read files with normalized line endings
var carriages = new RegExp(/\r/g);
app.post('/fs/cat', function(req, resp) {
    var out = {'res': []};
    var args = req.body.args;
	
	args.push(function callback(err, filedata) {
		if (err) {
			console.log(err);
			out.err = err;
		} else {
			out.res = filedata.replace(carriages, '');
		}
		resp.send(out);
	});
	
	fs.readFile.apply(this, args);
});

// List files and folders in a directory
app.post('/fs/listdir', function(req, resp) {
    var out = {'res': []};
    var args = req.body.args;
    
    function onfinish() {
        var files = out.res.filter(function(item) { return item.type === 'file'; });
        var folders = out.res.filter(function(item) { return item.type === 'folder'; });
        function sortFunction(item1, item2) {
            return item1.name.localeCompare(item2.name);
        }
        files.sort(sortFunction);
        folders.sort(sortFunction);
        out.res = [{'name': '..', 'path': path.resolve(args[0], '..'), type: 'folder'}].concat(folders).concat(files);
        return resp.send(out);
    }
    
    args.push(function callback(err, filelist) {
        if (err) {
            out['err'] = err;
			//console.log(err);
            return resp.send(out);
        
        } else if (filelist.length == 0) {
            onfinish();

        } else {
            filelist.forEach(function(filename) {
                fs.stat(path.join(args[0], filename), function(err, fileobj) {
                    if (err) {
                        out['err'] += err + '\n';
                        //console.log(err);
                    } else {
                        out.res.push({
                            'name': filename,
                            'path': path.normalize(path.join(args[0], filename)).split(path.sep).join('/'),
                            'type': fileobj.isFile() ? 'file' : 'folder'
                        });
                    }

                    if (out.res.length === filelist.length) {
                        onfinish();
                    }
                });
            })
        }
    });

    fs.readdir.apply(this, args);
});

// Perform a glob search for a pattern
app.post('/fs/glob', function(req, resp) {
    var out = {'res': []};
    var args = req.body.args;
    glob(args[0], function (err, files) {
        if (err) {
            console.log(err);
            out.err = err;
        } else {
            out.res = files;
        }
        resp.send(out);
    });
});

// Create a file if it does not exist, otherwise update timestamp
app.post('/fs/touch', function(req, resp) {
    var out = {'res': []};
    var args = req.body.args;

    // First check if it exists
    fs.stat(args[0], function(err, fileobj) {
        
        // Case 1: it doesn't exist -> Create file
        if (err) {
            out.res = {'isFile': true};
            fs.open(args[0], 'a', function (err, fd) {
                if (err) {
                    console.log(err);
                    out.err = err;
                    resp.send(out);
                } else {
                    fs.close(fd, function(err) {
                        if (err) {
                            console.log(err);
                            out.err = err;                            
                        }
                        resp.send(out);
                    });
                }
            });
            
        // Case 2: It exists and it's a folder
        } else if (!fileobj.isFile()) {
            out.res = {'isFile': false};
            resp.send(out);

        // Case 3: It exists and it's a file
        } else {
          	out.res = {'isFile': true};
            resp.send(out);
        }
    });
});

// Workaround for https://github.com/PolymerElements/neon-animation/issues/184
app.get('/node_modules/@polymer/web-animations-js/web-animations-next-lite.min.js', function(req, resp) {
    resp.redirect('/node_modules/web-animations-js/web-animations-next-lite.min.js');
});

portfinder.basePort = 5050;
portfinder.getPort(function (err, port) {
    if (err) {
        console.log(err);
    } else {
        var url = 'http://localhost:' + port;
        setTimeout(function() {
            open(url);
        }, 1000);
        console.log('Listening on ' + url);
        app.listen(port);
    }
});
